/*
 * Card_tools for raw access smile_XD/Smartmedia cards using Olympus MAUSB-10
 * author: warpjavier
 * email: warpjavier@hotmail.com
 * date: 27 May 2007
 * platform: linux + windows
 *
 */

#ifndef CARD_TOOLS_H_INCLUDED
#define CARD_TOOLS_H_INCLUDED

#include <usb.h>

/* the device's vendor and product id for Olympus MAUSB-10*/
#define MY_VID 0x07B4
#define MY_PID 0x010A

/* the device's endpoints */
#define EP_IN 0x82
#define EP_OUT 0x03

#define PBA_LO(pba) ((pba & 0xF) << 5)
#define PBA_HI(pba) (pba >> 3)

#define BUF_SIZE 576 //576 instead of 528 as the device return 48 extra bytes

/*
 * Bulk command identity (byte 0)
 */
#define CARD_TOOLS_BULK_CMD			0x40

/*
 * Bulk opcodes (byte 1)
 */
#define CARD_TOOLS_BULK_READ_BLOCK		0x94
#define CARD_TOOLS_BULK_ERASE_BLOCK		0xa3
#define CARD_TOOLS_BULK_WRITE_BLOCK		0xb4
#define CARD_TOOLS_BULK_RESET_MEDIA		0xe0

/*
 * Port to operate on (byte 8)
 */
#define CARD_TOOLS_PORT_smile_XD			0x00
#define CARD_TOOLS_PORT_SM			0x01

/*
 * Error Codes
 */
#define CARD_TOOLS_OK       0x00
#define CARD_TOOLS_ERROR    0x01

/*
 * Functions
 */
usb_dev_handle *open_dev(void);
int reset_media(void);
int dump_card(char *filename);
int write_to_card(char *filename);
int erase_card();
int read_block(unsigned short block);
int erase_block(unsigned short block);
int write_block(unsigned short block);
#endif // CARD_TOOLS_H_INCLUDED
